@@ -1,8 +1,4 @@
-from .redis_pubsub import RedisPubSub
-from .zmq_pubsub import ZMQPubSub
-from .constants import *
-
-VERSION = (0, 1, 0)
+VERSION = (0, 1, 1)
 __version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
 __description__ = 'Asynchronous PubSub in Python using Redis, ZMQ'
 __author__ = 'Abhinav Singh'
